@@ -9,13 +9,21 @@ class ErrorLevel(AutoName):
     RAISE = auto()
 
 
-class UnsupportedError(ValueError):
+class SqlglotError(Exception):
     pass
 
 
-class ParseError(ValueError):
+class UnsupportedError(SqlglotError):
     pass
 
 
-class TokenError(ValueError):
+class ParseError(SqlglotError):
+    pass
+
+
+class TokenError(SqlglotError):
+    pass
+
+
+class OptimizeError(SqlglotError):
     pass
