@@ -202,6 +202,15 @@ class Expression:
                         if isinstance(node, Expression):
                             queue.append((node, item, k))
 
+    def unnest(self):
+        """
+        Returns the first non parenthesis child or self.
+        """
+        expression = self
+        while isinstance(expression, Paren):
+            expression = expression.this
+        return expression
+
     def __repr__(self):
         return self.to_s()
 
@@ -265,7 +274,7 @@ class Expression:
         if not isinstance(new_node, Expression) or new_node is not node:
             return new_node
 
-        self._replace_children(
+        replace_children(
             new_node, lambda child: child.transform(fun, *args, copy=False, **kwargs)
         )
         return new_node
@@ -287,28 +296,10 @@ class Expression:
         if not self.parent:
             return
 
-        self._replace_children(
+        replace_children(
             self.parent, lambda child: expressions if child is self else child
         )
 
-    def _replace_children(self, node, fun):
-        for k, v in node.args.items():
-            is_list_arg = isinstance(v, list)
-
-            child_nodes = v if is_list_arg else [v]
-            new_child_nodes = []
-
-            for cn in child_nodes:
-                if isinstance(cn, Expression):
-                    cns = ensure_list(fun(cn))
-                    for child_node in cns:
-                        child_node.parent = node
-                else:
-                    cns = [cn]
-                new_child_nodes.extend(cns)
-
-            node.args[k] = new_child_nodes if is_list_arg else new_child_nodes[0]
-
     def assert_is(self, type_):
         """
         Assert that this `Expression` is an instance of `type_`.
@@ -1010,7 +1001,7 @@ class Select(Subqueryable, Expression):
             join.set("on", on)
 
         if join_alias:
-            join.set("this", alias_(join.args["this"], join_alias))
+            join.set("this", alias_(join.args["this"], join_alias, table=True))
         return _apply_list_builder(
             join,
             instance=self,
@@ -1867,12 +1858,15 @@ def _norm_arg(arg):
 
 
 def _all_functions():
-    predicate = (
-        lambda obj: inspect.isclass(obj)
-        and issubclass(obj, Func)
-        and obj not in (AggFunc, Anonymous, Func)
-    )
-    return [obj for _, obj in inspect.getmembers(sys.modules[__name__], predicate)]
+    return [
+        obj
+        for _, obj in inspect.getmembers(
+            sys.modules[__name__],
+            lambda obj: inspect.isclass(obj)
+            and issubclass(obj, Func)
+            and obj not in (AggFunc, Anonymous, Func),
+        )
+    ]
 
 
 ALL_FUNCTIONS = _all_functions()
@@ -2141,6 +2135,10 @@ def not_(expression, dialect=None, **opts):
     return Not(this=_wrap_operator(this))
 
 
+def paren(expression):
+    return Paren(this=expression)
+
+
 SAFE_IDENTIFIER_RE = re.compile(r"^[a-zA-Z][\w]*$")
 
 
@@ -2160,7 +2158,7 @@ def to_identifier(alias, quoted=None):
     return identifier
 
 
-def alias_(expression, alias, dialect=None, quoted=None, **opts):
+def alias_(expression, alias, table=False, dialect=None, quoted=None, **opts):
     """
     Create an Alias expression.
     Expample:
@@ -2172,6 +2170,7 @@ def alias_(expression, alias, dialect=None, quoted=None, **opts):
             If an Expression instance is passed, this is used as-is.
         alias (str or Identifier): the alias name to use. If the name has
             special charachters it is quoted.
+        alias (boolean): create a table alias, default false
         dialect (str): the dialect used to parse the input expression.
         **opts: other options to use to parse the input expressions.
 
@@ -2180,6 +2179,7 @@ def alias_(expression, alias, dialect=None, quoted=None, **opts):
     """
     exp = _maybe_parse(expression, dialect=dialect, parser_opts=opts)
     alias = to_identifier(alias, quoted=quoted)
+    alias = TableAlias(this=alias) if table else alias
 
     if "alias" in exp.arg_types:
         exp = exp.copy()
@@ -2210,6 +2210,28 @@ def subquery(expression, alias=None, dialect=None, **opts):
     return Select().from_(expression, dialect=dialect, **opts)
 
 
+def replace_children(expression, fun):
+    """
+    Replace children of an expression with the result of a lambda fun(child) -> exp.
+    """
+    for k, v in expression.args.items():
+        is_list_arg = isinstance(v, list)
+
+        child_nodes = v if is_list_arg else [v]
+        new_child_nodes = []
+
+        for cn in child_nodes:
+            if isinstance(cn, Expression):
+                cns = ensure_list(fun(cn))
+                for child_node in cns:
+                    child_node.parent = expression
+            else:
+                cns = [cn]
+            new_child_nodes.extend(cns)
+
+        expression.args[k] = new_child_nodes if is_list_arg else new_child_nodes[0]
+
+
 TRUE = Boolean(this=True)
 FALSE = Boolean(this=False)
 NULL = Null()
