@@ -68,7 +68,7 @@ class Generator:
         type_mapping=None,
         time_mapping=None,
         time_trie=None,
-        pretty=False,
+        pretty=None,
         identifier=None,
         identify=False,
         quote=None,
@@ -79,12 +79,14 @@ class Generator:
         unsupported_level=ErrorLevel.WARN,
     ):
         # pylint: disable=too-many-arguments
+        import sqlglot
+
         self.transforms = {**self.TRANSFORMS, **(transforms or {})}
         self.type_mapping = type_mapping or {}
         self.time_mapping = time_mapping or {}
         self.time_trie = time_trie
-        self.pretty = pretty
-        self.configured_pretty = pretty
+        self.pretty = pretty if pretty is not None else sqlglot.pretty
+        self.configured_pretty = self.pretty
         self.identifier = identifier or '"'
         self.identify = identify
         self.quote = quote or "'"
@@ -411,7 +413,6 @@ class Generator:
             for part in [
                 self.sql(expression, "catalog"),
                 self.sql(expression, "db"),
-                self.sql(expression, "table"),
                 self.sql(expression, "this"),
             ]
             if part
@@ -747,6 +748,9 @@ class Generator:
     def eq_sql(self, expression):
         return self.binary(expression, "=")
 
+    def escape_sql(self, expression):
+        return self.binary(expression, "ESCAPE")
+
     def gt_sql(self, expression):
         return self.binary(expression, ">")
 
