@@ -74,14 +74,17 @@ class Parser:
         TokenType.ALL,
         TokenType.ASC,
         TokenType.ALTER,
+        TokenType.BEGIN,
         TokenType.BUCKET,
         TokenType.CACHE,
         TokenType.COLLATE,
+        TokenType.COMMIT,
         TokenType.COUNT,
         TokenType.DEFAULT,
         TokenType.DELETE,
         TokenType.DESC,
         TokenType.ENGINE,
+        TokenType.ESCAPE,
         TokenType.EXPLAIN,
         TokenType.FALSE,
         TokenType.FILTER,
@@ -552,7 +555,7 @@ class Parser:
                 )
                 value = self.expression(exp.Schema, expressions=partitions)
         else:
-            value = self._parse_string()
+            value = self._parse_column()
 
         return self.expression(
             exp.Property,
@@ -1081,9 +1084,13 @@ class Parser:
         negate = self._match(TokenType.NOT)
 
         if self._match(TokenType.LIKE):
-            this = self.expression(exp.Like, this=this, expression=self._parse_term())
+            this = self._parse_escape(
+                self.expression(exp.Like, this=this, expression=self._parse_term())
+            )
         elif self._match(TokenType.ILIKE):
-            this = self.expression(exp.ILike, this=this, expression=self._parse_term())
+            this = self._parse_escape(
+                self.expression(exp.ILike, this=this, expression=self._parse_term())
+            )
         elif self._match(TokenType.RLIKE):
             this = self.expression(
                 exp.RegexpLike, this=this, expression=self._parse_term()
@@ -1111,6 +1118,11 @@ class Parser:
 
         return this
 
+    def _parse_escape(self, this):
+        if not self._match(TokenType.ESCAPE):
+            return this
+        return self.expression(exp.Escape, this=this, expression=self._parse_string())
+
     def _parse_bitwise(self):
         return self._parse_tokens(self._parse_term, self.BITWISE)
 
